from typing import List, Union

ONE_WEEK_MONDAY = "604800_Monday"

period_mapping = {
    "1m": 60,
    "3m": 180,
    "5m": 300,
    "15m": 900,
    "30m": 1800,
    "1h": 3600,
    "2h": 7200,
    "4h": 14400,
    "6h": 21600,
    "12h": 43200,
    "1d": 86400,
    "3d": 259200,
    "1w": 604800,
    "1w_monday": ONE_WEEK_MONDAY,
}


def resolve_periods(periods: List[Union[str, int]]) -> str:
    """
    Resolve a list of period values or labels to a comma separated string of
    period values accepted by Cryptowatch.

    See https://docs.cryptowat.ch/rest-api/markets/ohlc#period-values

    >>> resolve_periods([60, 180, 7200])
    '60,180,7200'
    >>> resolve_periods([60,180,'604800_Monday'])
    '60,180,604800_Monday'
    >>> resolve_periods(['1m', '30m', '1w_monday'])
    '60,1800,604800_Monday'
    >>> resolve_periods([60,'30m'])
    '60,1800'
    >>> resolve_periods(['3m', 180])
    '180'
    """
    period_values = set()
    for period in periods:
        if period == ONE_WEEK_MONDAY:
            period_values.add(period)
        elif isinstance(period, int):
            assert period in list(period_mapping.values())
            period_values.add(period)
        else:
            value = period_mapping.get(period)
            if value is None:
                raise ValueError(f"Invalid period label: {period}")
            period_values.add(value)

    return ",".join(sorted(map(str, period_values), key=lambda p: len(p)))



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pycwatch']

package_data = \
{'': ['*']}

install_requires = \
['api-client-pydantic>=2.0.0,<3.0.0',
 'api-client>=1.3.1,<2.0.0',
 'pydantic>=1.9.0,<2.0.0',
 'requests>=2.27.1,<3.0.0']

setup_kwargs = {
    'name': 'pycwatch',
    'version': '1.1.0',
    'description': 'An client library for the Cryptowatch Rest API.',
    'long_description': '# pycwatch\n\n[![Coverage](https://img.shields.io/codecov/c/github/ljnsn/pycwatch?color=%2334D058)](https://codecov.io/gh/ljnsn/pycwatch)\n[![Package version](https://img.shields.io/pypi/v/pycwatch?color=%2334D058&label=pypi%20package)](https://pypi.org/project/pycwatch)\n[![Python versions](https://img.shields.io/pypi/pyversions/pycwatch.svg)](https://pypi.org/project/pycwatch)\n[![Black style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n\nThe `pycwatch` library provides access to the [Cryptowatch API](https://docs.cryptowat.ch/rest-api/) and implements all resources of the REST API.\n\n## Installation\n\nEither install from pypi or clone this repository and install locally.\n\n```fish\npip install pycwatch\n```\n\n## Quick Start\n\nSee the [cryptowat.ch docs](https://docs.cryptowat.ch/rest-api) for available endpoints.\n\n```python\nfrom pycwatch import CryptoWatchClient\n\n# create api client\nclient = CryptoWatchClient()\n\n# get list of available assets\nassets = client.list_assets()\n# get some price info\nexchange, pair = "binance", "btceur"\nprice = client.get_market_price(exchange, pair)\n```\n\nIf you have an account at [cryptowat.ch](https://cryptowat.ch), you can either set your key as an environment variable or in the code.\n\n```bash\nexport CRYPTO_WATCH_KEY="my-awesome-key"\n```\n\nor\n\n```python\nfrom pycwatch import CryptoWatchClient\n\napi_key = "my-awesome-key"\nclient = CryptoWatchClient(api_key)\n```\n',
    'author': 'ljnsn',
    'author_email': '82611987+ljnsn@users.noreply.github.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/ljnsn/pycwatch',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
